@@ -3,14 +3,14 @@ import kubify.kubify as module_0
 
 def test_case_0():
     try:
-        var_0 = module_0.test_or_create_s3_artifacts_bucket()
+        module_0.test_or_create_s3_artifacts_bucket()
     except BaseException:
         pass
 
 
 def test_case_1():
     try:
-        var_0 = module_0.test_or_create_s3_artifacts_bucket()
+        module_0.test_or_create_s3_artifacts_bucket()
     except BaseException:
         pass
 
@@ -28,7 +28,7 @@ def test_case_3():
         int_0 = 10
         bool_0 = False
         tuple_0 = str_0, float_0, int_0, bool_0
-        var_0 = module_0.test_or_create_s3_artifacts_bucket(tuple_0)
+        module_0.test_or_create_s3_artifacts_bucket(tuple_0)
     except BaseException:
         pass
 
@@ -36,14 +36,14 @@ def test_case_3():
 def test_case_4():
     try:
         str_0 = "_8cI@9!+~uA:}=hO?;)%"
-        var_0 = module_0.test_or_create_s3_artifacts_bucket(str_0)
+        module_0.test_or_create_s3_artifacts_bucket(str_0)
     except BaseException:
         pass
 
 
 def test_case_5():
     try:
-        var_0 = module_0.test_or_create_s3_artifacts_bucket()
+        module_0.test_or_create_s3_artifacts_bucket()
     except BaseException:
         pass
 
@@ -51,13 +51,13 @@ def test_case_5():
 def test_case_6():
     try:
         float_0 = 2911.043
-        var_0 = module_0.test_or_create_s3_artifacts_bucket(float_0)
+        module_0.test_or_create_s3_artifacts_bucket(float_0)
     except BaseException:
         pass
 
 
 def test_case_7():
     try:
-        var_0 = module_0.test_or_create_s3_artifacts_bucket()
+        module_0.test_or_create_s3_artifacts_bucket()
     except BaseException:
         pass
